@@ -18,7 +18,7 @@ svtree <- function(...) {
   shiny::shinyApp(
     shiny::fluidPage(
       use_svgzoom(),
-      tags$head(tags$style(HTML("body {background-color: #9c9ca096;}"))),
+      shiny::tags$head(shiny::tags$style(shiny::HTML("body {background-color: #9c9ca096;}"))),
       vtreeOutput("vtree", width = "100%", height = "500px")),
     function(input, output, session) {
       output$vtree <- renderVtree(vtree(...,pngknit=FALSE))
